# idspy

[![Build Status](https://travis-ci.org/intercontinental-dictionary-series/idspy.svg?branch=master)](https://travis-ci.org/intercontinental-dictionary-series/idspy)
[![codecov](https://codecov.io/gh/intercontinental-dictionary-series/idspy/branch/master/graph/badge.svg)](https://codecov.io/gh/intercontinental-dictionary-series/idspy)
[![PyPI](https://img.shields.io/pypi/v/idspy.svg)](https://pypi.org/project/idspy)
